# Basic Example File

Some constant introduction.

<!--[[[fill table('project = ABC AND labels = RELEVANT_LABEL order by key ASC')]]]-->
<!--[[[end]]]-->

Here some other text following the table ...
